@@ -11,7 +11,7 @@
 
 #include "openpgpcertificatecreationdialog.h"
 
-#include "animatedexpander_p.h"
+#include "animatedexpander.h"
 #include "nameandemailwidget.h"
 #include "openpgpcertificatecreationconfig.h"
 #include "utils/compat.h"
@@ -26,7 +26,6 @@
 #include <KDateComboBox>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KSeparator>
 #include <KSharedConfig>
 
 #include <QCheckBox>
@@ -54,6 +53,8 @@ class OpenPGPCertificateCreationDialog::Private
     OpenPGPCertificateCreationDialog *const q;
 
     struct UI {
+        Q_DISABLE_COPY(UI)
+
         QLabel *infoLabel;
         KAdjustingScrollArea *scrollArea;
         NameAndEmailWidget *nameAndEmail;
@@ -65,8 +66,9 @@ class OpenPGPCertificateCreationDialog::Private
         QComboBox *keyAlgoCB;
         QLabel *keyAlgoLabel;
         AnimatedExpander *expander;
+        QCheckBox *teamCheckBox;
 
-        UI(QWidget *dialog)
+        explicit UI(QWidget *dialog)
         {
             auto mainLayout = new QVBoxLayout{dialog};
 
@@ -74,8 +76,6 @@ class OpenPGPCertificateCreationDialog::Private
             infoLabel->setWordWrap(true);
             mainLayout->addWidget(infoLabel);
 
-            mainLayout->addWidget(new KSeparator{Qt::Horizontal, dialog});
-
             scrollArea = new KAdjustingScrollArea{dialog};
             scrollArea->setFocusPolicy(Qt::NoFocus);
             scrollArea->setFrameStyle(QFrame::NoFrame);
@@ -129,12 +129,14 @@ class OpenPGPCertificateCreationDialog::Private
                 advancedLayout->addLayout(hbox);
             }
 
+            teamCheckBox = new QCheckBox(i18nc("@option:check", "Set up this key for shared usage in teams"));
+            teamCheckBox->setVisible(false);
+            advancedLayout->addWidget(teamCheckBox);
+
             scrollAreaLayout->addStretch(1);
 
             mainLayout->addWidget(scrollArea);
 
-            mainLayout->addWidget(new KSeparator{Qt::Horizontal, dialog});
-
             buttonBox = new QDialogButtonBox{QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dialog};
 
             mainLayout->addWidget(buttonBox);
@@ -239,7 +241,9 @@ public:
         });
         updateTechnicalParameters(); // set key parameters to default values for OpenPGP
         connect(ui.expander, &AnimatedExpander::startExpanding, q, [this]() {
-            q->resize(std::max(q->sizeHint().width(), ui.expander->contentWidth()) + 20, q->sizeHint().height() + ui.expander->contentHeight() + 20);
+            const auto sh = q->sizeHint();
+            const auto margins = q->layout()->contentsMargins();
+            q->resize(std::max(sh.width(), ui.expander->contentWidth() + margins.left() + margins.right()), sh.height() + ui.expander->contentHeight());
         });
     }
 
@@ -251,7 +255,9 @@ private:
         auto subkeyType = GpgME::Subkey::AlgoUnknown;
         auto algoString = ui.keyAlgoCB->currentData().toString();
         if (algoString.startsWith(QStringLiteral("rsa"))) {
+            // cppcheck-suppress redundantInitialization
             keyType = GpgME::Subkey::AlgoRSA;
+            // cppcheck-suppress redundantInitialization
             subkeyType = GpgME::Subkey::AlgoRSA;
             const auto strength = algoString.mid(3).toInt();
             technicalParameters.setKeyLength(strength);
@@ -391,7 +397,9 @@ OpenPGPCertificateCreationDialog::OpenPGPCertificateCreationDialog(QWidget *pare
     : QDialog{parent, f}
     , d(new Private{this})
 {
-    resize(std::max(sizeHint().width(), d->ui.expander->contentWidth()) + 20, sizeHint().height() + 20);
+    const auto sh = sizeHint();
+    const auto margins = layout()->contentsMargins();
+    resize(std::max(sh.width(), d->ui.expander->contentWidth() + margins.left() + margins.right()), sh.height());
 }
 
 OpenPGPCertificateCreationDialog::~OpenPGPCertificateCreationDialog() = default;
@@ -423,6 +431,8 @@ void Kleo::OpenPGPCertificateCreationDialog::setKeyParameters(const Kleo::KeyPar
     if (!emails.empty()) {
         setEmail(emails.front());
     }
+
+    d->ui.teamCheckBox->setChecked(parameters.keyUsage().isGroupKey());
     d->setTechnicalParameters(parameters);
 }
 
@@ -436,6 +446,12 @@ KeyParameters OpenPGPCertificateCreationDialog::keyParameters() const
     if (!email().isEmpty()) {
         parameters.setEmail(email());
     }
+
+    auto usage = parameters.keyUsage();
+    usage.setIsGroupKey(d->ui.teamCheckBox->isChecked());
+    usage.setCanSign(!d->ui.teamCheckBox->isChecked());
+    parameters.setKeyUsage(usage);
+
     return parameters;
 }
 
@@ -449,4 +465,34 @@ bool OpenPGPCertificateCreationDialog::protectKeyWithPassword() const
     return d->ui.withPassCheckBox->isChecked();
 }
 
+void OpenPGPCertificateCreationDialog::setInfoText(const QString &text)
+{
+    d->ui.infoLabel->setText(text);
+}
+
+void OpenPGPCertificateCreationDialog::setNameLabel(const QString &nameLabel)
+{
+    d->ui.nameAndEmail->setNameLabel(nameLabel);
+}
+
+void OpenPGPCertificateCreationDialog::setEmailLabel(const QString &emailLabel)
+{
+    d->ui.nameAndEmail->setEmailLabel(emailLabel);
+}
+
+bool OpenPGPCertificateCreationDialog::isTeamKey() const
+{
+    return d->ui.teamCheckBox->isChecked();
+}
+
+void OpenPGPCertificateCreationDialog::showTeamKeyOption(bool show)
+{
+    d->ui.teamCheckBox->setVisible(show);
+}
+
+QString OpenPGPCertificateCreationDialog::algoString() const
+{
+    return d->ui.keyAlgoCB->currentData().toString();
+}
+
 #include "moc_openpgpcertificatecreationdialog.cpp"
