@@ -7,11 +7,12 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEO_PROGRESSBAR_H__
-#define __KLEO_PROGRESSBAR_H__
+#pragma once
 
 #include "kleo_export.h"
+
 #include <QProgressBar>
+
 class QTimer;
 
 namespace Kleo
@@ -52,5 +53,3 @@ private:
     int mRealProgress;
 };
 }
-
-#endif // __KLEO_PROGRESSBAR_H__
