@@ -20,7 +20,7 @@
 #include "gnupg.h"
 #include "keyhelpers.h"
 
-#include <libkleo/dn.h>
+#include <libkleo/dnattributes.h>
 #include <libkleo/keycache.h>
 #include <libkleo/keygroup.h>
 
@@ -30,6 +30,7 @@
 #include <KLocalizedString>
 
 #include <QGpgME/CryptoConfig>
+#include <QGpgME/DN>
 #include <QGpgME/Protocol>
 
 #include <QDateTime>
@@ -108,17 +109,17 @@ QIcon Formatting::IconProvider::icon(const KeyGroup &group) const
 
 QIcon Formatting::successIcon()
 {
-    return QIcon::fromTheme(QStringLiteral("emblem-success"));
+    return QIcon::fromTheme(QStringLiteral("data-success"));
 }
 
 QIcon Formatting::infoIcon()
 {
-    return QIcon::fromTheme(QStringLiteral("emblem-information"));
+    return QIcon::fromTheme(QStringLiteral("data-information"));
 }
 
 QIcon Formatting::questionIcon()
 {
-    return QIcon::fromTheme(QStringLiteral("emblem-question"));
+    return QIcon::fromTheme(QStringLiteral("data-question"), QIcon::fromTheme(QStringLiteral("dialog-question")));
 }
 
 QIcon Formatting::unavailableIcon()
@@ -128,12 +129,12 @@ QIcon Formatting::unavailableIcon()
 
 QIcon Formatting::warningIcon()
 {
-    return QIcon::fromTheme(QStringLiteral("emblem-warning"));
+    return QIcon::fromTheme(QStringLiteral("data-warning"));
 }
 
 QIcon Formatting::errorIcon()
 {
-    return QIcon::fromTheme(QStringLiteral("emblem-error"));
+    return QIcon::fromTheme(QStringLiteral("data-error"));
 }
 
 //
@@ -155,9 +156,10 @@ QString Formatting::prettyName(int proto, const char *id, const char *name_, con
     }
 
     if (proto == GpgME::CMS) {
-        const DN subject(id);
+        const QGpgME::DN subject(id);
         const QString cn = subject[QStringLiteral("CN")].trimmed();
         if (cn.isEmpty()) {
+            subject.setAttributeOrder(DNAttributes::order());
             return subject.prettyDN();
         }
         return cn;
@@ -198,9 +200,10 @@ QString Formatting::prettyNameAndEMail(int proto, const QString &id, const QStri
     }
 
     if (proto == GpgME::CMS) {
-        const DN subject(id);
+        const QGpgME::DN subject(id);
         const QString cn = subject[QStringLiteral("CN")].trimmed();
         if (cn.isEmpty()) {
+            subject.setAttributeOrder(DNAttributes::order());
             return subject.prettyDN();
         }
         return cn;
@@ -221,7 +224,7 @@ QString Formatting::prettyUserID(const UserID &uid)
         // ### parse uri/dns:
         return QString::fromUtf8(uid.id());
     } else {
-        return DN(uid.id()).prettyDN();
+        return prettyDN(uid.id());
     }
 }
 
@@ -291,10 +294,17 @@ QString Formatting::prettyEMail(const char *email_, const char *id)
     if (email_ && KEmailAddress::splitAddress(QString::fromUtf8(email_), name, email, comment) == KEmailAddress::AddressOk) {
         return email;
     } else {
-        return DN(id)[QStringLiteral("EMAIL")].trimmed();
+        return QGpgME::DN(id)[QStringLiteral("EMAIL")].trimmed();
     }
 }
 
+QString Formatting::prettyDN(const char *utf8DN)
+{
+    QGpgME::DN dn{utf8DN};
+    dn.setAttributeOrder(DNAttributes::order());
+    return dn.prettyDN();
+}
+
 //
 // Tooltip
 //
@@ -333,16 +343,6 @@ QString format_keytype(const Key &key)
     }
 }
 
-QString format_subkeytype(const Subkey &subkey)
-{
-    const auto algo = subkey.publicKeyAlgorithm();
-
-    if (algo == Subkey::AlgoECC || algo == Subkey::AlgoECDSA || algo == Subkey::AlgoECDH || algo == Subkey::AlgoEDDSA) {
-        return QString::fromStdString(subkey.algoName());
-    }
-    return i18n("%1-bit %2", subkey.length(), QLatin1StringView(subkey.publicKeyAlgorithmAsString()));
-}
-
 QString format_keyusage(const Key &key)
 {
     QStringList capabilities;
@@ -365,28 +365,6 @@ QString format_keyusage(const Key &key)
     return capabilities.join(QLatin1StringView(", "));
 }
 
-QString format_subkeyusage(const Subkey &subkey)
-{
-    QStringList capabilities;
-    if (subkey.canSign()) {
-        if (subkey.isQualified()) {
-            capabilities.push_back(i18n("Signing (Qualified)"));
-        } else {
-            capabilities.push_back(i18n("Signing"));
-        }
-    }
-    if (subkey.canEncrypt()) {
-        capabilities.push_back(i18n("Encryption"));
-    }
-    if (subkey.canCertify()) {
-        capabilities.push_back(i18n("Certifying User IDs"));
-    }
-    if (subkey.canAuthenticate()) {
-        capabilities.push_back(i18n("SSH Authentication"));
-    }
-    return capabilities.join(QLatin1StringView(", "));
-}
-
 static QString time_t2string(time_t t)
 {
     const QDateTime dt = QDateTime::fromSecsSinceEpoch(quint32(t));
@@ -500,7 +478,7 @@ static QString toolTipInternal(const GpgME::Key &key, const GpgME::UserID &userI
         result += format_row(i18n("Key ID"), QString::fromLatin1(key.keyID()));
     }
     if (flags & Formatting::Fingerprint) {
-        result += format_row(i18n("Fingerprint"), key.primaryFingerprint());
+        result += format_row(i18n("Fingerprint"), Formatting::prettyID(key.primaryFingerprint()));
     }
     if (flags & Formatting::OwnerTrust) {
         if (key.protocol() == GpgME::OpenPGP) {
@@ -516,38 +494,6 @@ static QString toolTipInternal(const GpgME::Key &key, const GpgME::UserID &userI
             result += format_row(i18n("Stored"), i18nc("stored...", "on this computer"));
         }
     }
-    if (flags & Formatting::Subkeys) {
-        for (const auto &sub : key.subkeys()) {
-            result += QLatin1StringView("<hr/>");
-            result += format_row(i18n("Subkey"), sub.fingerprint());
-            if (sub.isRevoked()) {
-                result += format_row(i18n("Status"), i18n("Revoked"));
-            } else if (sub.isExpired()) {
-                result += format_row(i18n("Status"), i18n("Expired"));
-            }
-            if (flags & Formatting::ExpiryDates) {
-                result += format_row(i18n("Valid from"), time_t2string(sub.creationTime()));
-
-                if (!sub.neverExpires()) {
-                    result += format_row(i18n("Valid until"), time_t2string(sub.expirationTime()));
-                }
-            }
-
-            if (flags & Formatting::CertificateType) {
-                result += format_row(i18n("Type"), format_subkeytype(sub));
-            }
-            if (flags & Formatting::CertificateUsage) {
-                result += format_row(i18n("Usage"), format_subkeyusage(sub));
-            }
-            if (flags & Formatting::StorageLocation) {
-                if (const char *card = sub.cardSerialNumber()) {
-                    result += format_row(i18n("Stored"), i18nc("stored...", "on SmartCard with serial no. %1", QString::fromUtf8(card)));
-                } else {
-                    result += format_row(i18n("Stored"), i18nc("stored...", "on this computer"));
-                }
-            }
-        }
-    }
     result += QLatin1StringView("</table>");
 
     return result;
@@ -1006,7 +952,7 @@ QString Formatting::formatForComboBox(const GpgME::Key &key)
     if (!mail.isEmpty()) {
         mail = QLatin1Char('<') + mail + QLatin1Char('>');
     }
-    return i18nc("name, email, key id", "%1 %2 (%3)", name, mail, QLatin1StringView(key.keyID())).simplified();
+    return i18nc("name, email, key id", "%1 %2 (%3)", name, mail, Formatting::prettyID(key.keyID())).simplified();
 }
 
 QString Formatting::nameAndEmailForSummaryLine(const UserID &id)
@@ -1141,15 +1087,6 @@ QString Formatting::importMetaData(const Import &import)
     return results.empty() ? i18n("The import contained no new data for this certificate. It is unchanged.") : results.join(QLatin1Char('\n'));
 }
 
-//
-// Overview in CertificateDetailsDialog
-//
-
-QString Formatting::formatOverview(const Key &key)
-{
-    return toolTip(key, AllOptions);
-}
-
 QString Formatting::usageString(const Subkey &sub)
 {
     QStringList usageStrings;
@@ -1539,6 +1476,10 @@ QString Formatting::prettyAlgorithmName(const std::string &algorithm)
         {"elg2048", i18nc("@info", "Elgamal 2048")},
         {"elg3072", i18nc("@info", "Elgamal 3072")},
         {"elg4096", i18nc("@info", "Elgamal 4096")},
+        {"ky768_cv25519", i18nc("@info", "Kyber 768 (Curve25519)")},
+        {"ky768_bp256", i18nc("@info", "Kyber 768 (Brainpool P-256)")},
+        {"ky1024_bp384", i18nc("@info", "Kyber 1024 (Brainpool P-384)")},
+        {"ky1024_cv448", i18nc("@info", "Kyber 1024 (Curve448)")},
     };
     const auto it = displayNames.find(algorithm);
     return (it != displayNames.end()) ? it->second : QString::fromStdString(algorithm);
@@ -1676,7 +1617,7 @@ QString Formatting::email(const GpgME::UserID &uid)
         if (id[0] == '<') {
             return stripAngleBrackets(id).toString();
         }
-        return Kleo::DN(id)[QStringLiteral("EMAIL")].trimmed();
+        return QGpgME::DN(id)[QStringLiteral("EMAIL")].trimmed();
     }
     return {};
 }
